@@ -6,7 +6,7 @@ use Mojo::Util   ();
 use Scalar::Util ();
 use Sub::Quote   ();
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our @EXPORT_OK = qw(remove_trailing_slashes);
 
@@ -358,7 +358,7 @@ sub _create_should_canonicalize_request_sub_string {
 }
 
 sub _get_should_canonicalize_request_config_name {
-    return shift ? 'should_canonicalize_request' : 'should_not_canonicalize_request';
+    return shift() ? 'should_canonicalize_request' : 'should_not_canonicalize_request';
 }
 
 sub remove_trailing_slashes {
